@@ -3,12 +3,12 @@ package aws
 import (
 	"strings"
 
-	"github.com/cloudskiff/driftctl/pkg/remote/aws/repository"
+	"github.com/snyk/driftctl/pkg/remote/aws/repository"
 
-	remoteerror "github.com/cloudskiff/driftctl/pkg/remote/error"
+	remoteerror "github.com/snyk/driftctl/pkg/remote/error"
 
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	resourceaws "github.com/cloudskiff/driftctl/pkg/resource/aws"
+	"github.com/snyk/driftctl/pkg/resource"
+	resourceaws "github.com/snyk/driftctl/pkg/resource/aws"
 )
 
 type Route53ZoneSupplier struct {
